package javax.swing;

import java.awt.Frame;
import java.awt.Graphics;
import sun.awt.ModalExclude;
import java.awt.GraphicsEnvironment;
import java.awt.Window;
import java.awt.Component;

public class Popup
{
    private Component component;
    
    protected Popup(Component component, Component component2, int n, int n2) {
        this();
        if (component2 == null) {
            throw new IllegalArgumentException("Contents must be non-null");
        }
        this.reset(component, component2, n, n2);
        return;
    }
    
    protected Popup() {
    }
    
    public void show() {
        Component component = this.getComponent();
        if (component != null) {
            component.show();
        }
    }
    
    public void hide() {
        Component component = this.getComponent();
        if ((component instanceof JWindow)) {
            component.hide();
            ((JWindow)component).getContentPane().removeAll();
        }
        this.dispose();
    }
    
    void dispose() {
        Component component = this.getComponent();
        Window windowAncestor = SwingUtilities.getWindowAncestor(component);
        if ((component instanceof JWindow)) {
            ((Window)component).dispose();
        }
        if ((windowAncestor instanceof Popup.DefaultFrame)) {
            windowAncestor.dispose();
        }
    }
    
    void reset(Component component, Component comp, int x, int y) {
        if (this.getComponent() == null) {
            this.component = this.createComponent(component);
        }
        if ((this.getComponent() instanceof JWindow)) {
            JWindow window = (JWindow)this.getComponent();
            window.setLocation(x, y);
            window.getContentPane().add(comp, "Center");
            window.invalidate();
            window.validate();
            if (window.isVisible()) {
                this.pack();
            }
        }
    }
    
    void pack() {
        Component component = this.getComponent();
        if ((component instanceof Window)) {
            ((Window)component).pack();
        }
    }
    
    private Window getParentWindow(Component component) {
        Object windowAncestor = null;
        if ((component instanceof Window)) {
            windowAncestor = (Component)component;
        }
        else if (component != null) {
            windowAncestor = SwingUtilities.getWindowAncestor(component);
        }
        if (windowAncestor == null) {
            windowAncestor = new Popup.DefaultFrame();
            return windowAncestor;
        }
        return windowAncestor;
    }
    
    Component createComponent(Component component) {
        if (GraphicsEnvironment.isHeadless()) {
            return null;
        }
        return new Popup.HeavyWeightWindow(this.getParentWindow(component));
    }
    
    Component getComponent() {
        return this.component;
    }
    
    static class HeavyWeightWindow extends JWindow implements ModalExclude
    {
        HeavyWeightWindow(Window window) {
            super(window);
            this.setFocusableWindowState(false);
            this.setType(Window.Type.POPUP);
            this.getRootPane().setUseTrueDoubleBuffering(false);
            try {
                this.setAlwaysOnTop(true);
            }
            catch (SecurityException ex) {}
        }
        
        @Override
        public void update(Graphics g) {
            this.paint(g);
        }
        
        @Override
        public void show() {
            this.pack();
            if (this.getWidth() > 0 && this.getHeight() > 0) {
                super.show();
            }
        }
    }
    
    static class DefaultFrame extends Frame
    {
    }
}
